from ...basic import Basic


class MetroAnimationBase(Basic):

    from MetroFramework.Animation import AnimationBase

    _type = AnimationBase

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)



from .metro_control import MetroControl


class MetroTabControl(MetroControl):

    from MetroFramework.Controls import MetroTabControl

    _type = MetroTabControl

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    from .metro_tab_page import MetroTabPage

    def CreatePage(self, Text: str = "") -> MetroTabPage:
        from .metro_tab_page import MetroTabPage
        _Page = MetroTabPage(self)
        _Page.Text = Text
        _Page.Pack(Dock="Fill")
        return _Page


from .metro_control import MetroControl


class MetroPanel(MetroControl):

    from MetroFramework.Controls import MetroPanel

    _type = MetroPanel

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)


from .metro_form import MetroForm


class MetroMessageBox(MetroForm):
    from MetroFramework.Forms import MetroMessageBox

    _type = MetroMessageBox

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)



from os import environ
environ["aquaref.LOG.ENABLE"] = "true"

from aquaref.winforms.metro import *
from aquaref import *

from os import environ

window = MetroForm()
window.Title = "aquaref.Metro"

tooltip = MetroToolTip()

tab = window.Create(MetroTab)
tab.Pack(Dock="Fill")

input = tab.CreatePage("Inputs")

button1 = input.Create(MetroButton)
button1.Text = "A Base Button"
button1.Pack(Dock="Top")

config = tab.CreatePage("Config")
system = config.Create(MetroButton)
system.Text = "System"
system.Bind("Click", lambda e1, e2: window.StyleManager.SetTheme("System"))
system.Pack(Dock="Top")

dark = config.Create(MetroButton)
dark.Text = "Dark"
dark.Bind("Click", lambda e1, e2: window.StyleManager.SetTheme("Dark"))
dark.Pack(Dock="Top")

light = config.Create(MetroButton)
light.Text = "Light"
light.Bind("Click", lambda e1, e2: window.StyleManager.SetTheme("Light"))
light.Pack(Dock="Top", Margin=10)

theme = config.Create(MetroLabel)
theme.Text = "Theme"
theme.Pack(Dock="Top")

window.StyleManager.Theme = "Dark"
window.StyleManager.Style = "Red"

window.AppRun()

SaveLog("test.metro.1.log")



import os
dir = os.path.abspath(os.path.dirname(__file__))

dir_metro = os.path.join(dir, "metro")
dir_metro_net40 = os.path.join(dir_metro, "net40")

libs = {}

if os.path.exists(dir_metro_net40):
    for lib in os.listdir(dir_metro_net40):
        path = os.path.join(dir_metro_net40, lib)
        if os.path.isfile(path):
            if os.path.splitext(path)[1] == ".dll":  # 判断文件扩展名是否为“.dll”
                libs[lib] = path

from aquareflog import Debug
Debug(f"MetroFramework Library Files {libs}")


from ...basic import Basic
from ..tooltip import ToolTip


class MetroToolTip(ToolTip, Basic):

    from MetroFramework.Components import MetroToolTip

    _type = MetroToolTip

    def __init__(self):
        super().__init__()



from ... import LoadMetro

LoadMetro()

from .metro_button import MetroButton
from .metro_control import MetroControl
from .metro_form import MetroForm
from .metro_label import MetroLabel
from .metro_messagebox import MetroMessageBox
from .metro_panel import MetroPanel
from .metro_style_manager import MetroStyleManager
from .metro_tab_control import MetroTabControl
from .metro_tab_control import MetroTabControl as MetroTab
from .metro_tab_page import MetroTabPage
from .metro_tooltip import MetroToolTip



from .metro_control import MetroControl
from ..label import Label


class MetroLabel(MetroControl, Label):

    from MetroFramework.Controls import MetroLabel

    _type = MetroLabel

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)


from .metro_control import MetroControl


class MetroTabPage(MetroControl):

    from MetroFramework.Controls import MetroTabPage

    _type = MetroTabPage

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)